@@ -3,24 +3,6 @@
 from pygroupsig.common_build import ffibuilder
 import pygroupsig.types_build
 
-ffibuilder.cdef("""
-typedef enum {
-MESSAGE_FORMAT_NULL_FILE,
-MESSAGE_FORMAT_STRING_B64,
-} message_format_t;
-""")
-
-ffibuilder.cdef("""
-#define SUPPORTED_MESSAGE_FORMATS_N 2
-""")
-
-ffibuilder.cdef("""
-static const int SUPPORTED_MESSAGE_FORMATS[SUPPORTED_MESSAGE_FORMATS_N] = { 
-MESSAGE_FORMAT_NULL_FILE,
-MESSAGE_FORMAT_STRING_B64,
-};
-""")
-
 ffibuilder.cdef("""                
 typedef struct _message_t {
 byte_t *bytes;
@@ -60,14 +42,6 @@ ffibuilder.cdef("""
 char* message_to_string(message_t *msg);
 """)
 
-ffibuilder.cdef("""                
-int message_export(void *dst, message_format_t, message_t *msg);
-""")
-
-ffibuilder.cdef("""
-int message_import(message_t *msg, message_format_t format, void *src);
-""")
-
 ffibuilder.cdef("""
 char* message_to_base64(message_t *msg);
 """)
